
import React from 'react';
import { Link } from 'react-router-dom';
import { ArrowRight, BarChart3, Layers, Shield } from 'lucide-react';

const Hero = () => {
  return (
    <section className="pt-32 pb-16 md:pt-40 md:pb-24 relative overflow-hidden">
      <div className="absolute inset-0 -z-10">
        <div className="absolute top-10 left-1/2 w-full h-[500px] -translate-x-1/2 bg-gradient-radial from-red-500/10 to-transparent opacity-70"></div>
      </div>

      <div className="container max-w-6xl mx-auto px-4">
        <div className="flex flex-col items-center text-center max-w-3xl mx-auto">
          <div className="inline-block px-4 py-1.5 bg-brand-red/10 rounded-full text-brand-red text-sm font-medium mb-6 animate-fade-in">
            <span className="mr-2">CIFT</span> •<span className="ml-2">AI-Powered Credit Risk Assessment</span>
          </div>

          <h1 className="heading-xl mb-6 animate-fade-up" style={{ animationDelay: '0.1s' }}>
            Next-Generation <span className="text-brand-red">Credit Risk</span> Assessment Platform
          </h1>

          <p className="subtitle mb-8 max-w-2xl animate-fade-up" style={{ animationDelay: '0.2s' }}>
            Leverage advanced AI to predict loan and credit card defaults with precision.
            Empower your financial decisions with data-driven insights and risk scoring.
          </p>

          <div className="flex flex-col items-center mb-16 animate-fade-up" style={{ animationDelay: '0.3s' }}>
            <Link 
              to="/assessment" 
              className="button-primary flex items-center justify-center gap-2 animate-pulse shadow-lg shadow-brand-red/20 hover:shadow-brand-red/40 transition-all duration-500"
            >
              Start New Assessment
              <ArrowRight size={18} />
            </Link>
          </div>

          <div className="glass-panel p-6 w-full max-w-4xl mx-auto animate-fade-up" style={{ animationDelay: '0.4s' }}>
            <div className="grid grid-cols-1 md:grid-cols-3 gap-6 text-left">
              <div className="flex flex-col">
                <div className="p-3 bg-brand-red/10 rounded-full w-12 h-12 flex items-center justify-center mb-4">
                  <Shield className="text-brand-red" />
                </div>
                <h3 className="font-display font-medium text-lg mb-2">AI-Powered Accuracy</h3>
                <p className="text-muted-foreground text-sm">Advanced algorithms that predict default risk with superior precision.</p>
              </div>
              
              <div className="flex flex-col">
                <div className="p-3 bg-brand-red/10 rounded-full w-12 h-12 flex items-center justify-center mb-4">
                  <BarChart3 className="text-brand-red" />
                </div>
                <h3 className="font-display font-medium text-lg mb-2">Visual Insights</h3>
                <p className="text-muted-foreground text-sm">Comprehensive dashboards with visual metrics for informed decisions.</p>
              </div>
              
              <div className="flex flex-col">
                <div className="p-3 bg-brand-red/10 rounded-full w-12 h-12 flex items-center justify-center mb-4">
                  <Layers className="text-brand-red" />
                </div>
                <h3 className="font-display font-medium text-lg mb-2">Multi-Factor Analysis</h3>
                <p className="text-muted-foreground text-sm">Consider all relevant variables for a holistic risk assessment.</p>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default Hero;
